@@ -6,8 +6,6 @@ STEMDIFF package
 Convert a 4D-STEM dataset to a single powder diffraction pattern.
 '''
 
-__version__ = '4.2.5'
-
-__all__ = ['const','io','dbase','psf','sum','radial']
+__version__ = "4.2.6"
 
 
